"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOutputTokenAmount = getOutputTokenAmount;
exports.getOutputSolAmount = getOutputSolAmount;
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
const anchor_1 = require("@coral-xyz/anchor");
const constants_1 = require("./constants");
function getOutputTokenAmount(inputSolAmount_, virtualSolReserve_, virtualTokenReserve_) {
    const inputSolAmount = new anchor_1.BN(inputSolAmount_);
    const virtualSolReserve = new anchor_1.BN(virtualSolReserve_);
    const virtualTokenReserve = new anchor_1.BN(virtualTokenReserve_);
    let tax = inputSolAmount
        .mul(new anchor_1.BN(constants_1.BONDING_CURVE_FEE_BIPS))
        .div(new anchor_1.BN(constants_1.PRECISION));
    let amountBuy = inputSolAmount.sub(tax);
    let virtualTokenReserveAfter = virtualSolReserve
        .mul(virtualTokenReserve)
        .div(virtualSolReserve.add(amountBuy));
    if (virtualTokenReserveAfter
        .mul(virtualSolReserve.add(amountBuy))
        .lt(virtualSolReserve.mul(virtualTokenReserve))) {
        virtualTokenReserveAfter = virtualTokenReserveAfter.add(new anchor_1.BN(1));
    }
    let amountOut;
    let remainSolAmount = new anchor_1.BN(0);
    if (virtualTokenReserveAfter.lt(new anchor_1.BN(constants_1.VIRTUAL_TOKEN_RESERVE_WHEN_ADD_LIQUIDITY))) {
        amountOut = virtualTokenReserve.sub(new anchor_1.BN(constants_1.VIRTUAL_TOKEN_RESERVE_WHEN_ADD_LIQUIDITY));
        let virtualSolReserveAfter = virtualSolReserve
            .mul(virtualTokenReserve)
            .div(new anchor_1.BN(constants_1.VIRTUAL_TOKEN_RESERVE_WHEN_ADD_LIQUIDITY));
        if (virtualSolReserveAfter
            .mul(new anchor_1.BN(constants_1.VIRTUAL_TOKEN_RESERVE_WHEN_ADD_LIQUIDITY))
            .lt(virtualSolReserve.mul(virtualTokenReserve))) {
            virtualSolReserveAfter = virtualSolReserveAfter.add(new anchor_1.BN(1));
        }
        amountBuy = virtualSolReserveAfter.sub(virtualSolReserve);
        tax = amountBuy
            .mul(new anchor_1.BN(constants_1.BONDING_CURVE_FEE_BIPS))
            .div(new anchor_1.BN(constants_1.PRECISION - constants_1.BONDING_CURVE_FEE_BIPS));
        remainSolAmount = inputSolAmount.sub(amountBuy).sub(tax);
    }
    else {
        amountOut = virtualTokenReserve.sub(virtualTokenReserveAfter);
    }
    return { amountOut, tax, remainSolAmount };
}
function getOutputSolAmount(inputTokenAmount_, virtualSolReserve_, virtualTokenReserve_) {
    const inputTokenAmount = new anchor_1.BN(inputTokenAmount_);
    const virtualSolReserve = new anchor_1.BN(virtualSolReserve_);
    const virtualTokenReserve = new anchor_1.BN(virtualTokenReserve_);
    let virtualSolReserveAfter = virtualSolReserve
        .mul(virtualTokenReserve)
        .div(virtualTokenReserve.add(inputTokenAmount));
    if (virtualSolReserveAfter
        .mul(virtualTokenReserve.add(inputTokenAmount))
        .lt(virtualSolReserve.mul(virtualTokenReserve))) {
        virtualSolReserveAfter = virtualSolReserveAfter.add(new anchor_1.BN(1));
    }
    const outBeforeTax = virtualSolReserve.sub(virtualSolReserveAfter);
    const tax = outBeforeTax
        .mul(new anchor_1.BN(constants_1.BONDING_CURVE_FEE_BIPS))
        .div(new anchor_1.BN(constants_1.PRECISION));
    return { outputSol: outBeforeTax.sub(tax), tax };
}
