/**
 * Program IDL in camelCase format in order to be used in JS/TS.
 *
 * Note that this is only a type helper and is not the actual IDL. The original
 * IDL can be found at `target/idl/omnipump_solana.json`.
 */
export type OmnipumpSolana = {
    address: 'BiJy9yoF5jPadmi7za3WX7HDzBw1UVLDqkDnajoeuPUH';
    metadata: {
        name: 'omnipumpSolana';
        version: '0.1.0';
        spec: '0.1.0';
        description: 'Created with Anchor';
    };
    instructions: [
        {
            name: 'addLiquidity';
            discriminator: [181, 157, 89, 67, 143, 182, 52, 72];
            accounts: [
                {
                    name: 'creator';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'mint';
                    writable: true;
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'bondingCurveWsolAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'bondingCurve';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram';
                            },
                            {
                                kind: 'account';
                                path: 'wsol';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'bondingCurveAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'bondingCurve';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram2022';
                            },
                            {
                                kind: 'account';
                                path: 'mint';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'raydiumCp';
                },
                {
                    name: 'ammConfig';
                },
                {
                    name: 'authority';
                },
                {
                    name: 'poolState';
                    writable: true;
                },
                {
                    name: 'wsol';
                },
                {
                    name: 'lpMint';
                    writable: true;
                },
                {
                    name: 'creatorWsolAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'creator';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram';
                            },
                            {
                                kind: 'account';
                                path: 'wsol';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'creatorTokenAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'creator';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram2022';
                            },
                            {
                                kind: 'account';
                                path: 'mint';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'creatorLpToken';
                    writable: true;
                },
                {
                    name: 'token0Vault';
                    writable: true;
                },
                {
                    name: 'token1Vault';
                    writable: true;
                },
                {
                    name: 'createPoolFee';
                    writable: true;
                },
                {
                    name: 'observationState';
                    writable: true;
                },
                {
                    name: 'tokenProgram';
                    docs: ['Program to create mint account and mint tokens'];
                    address: 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA';
                },
                {
                    name: 'tokenProgram2022';
                    docs: ['Spl token program or token program 2022'];
                },
                {
                    name: 'associatedTokenProgram';
                    docs: ['Program to create an ATA for receiving position NFT'];
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'systemProgram';
                    docs: ['To create a new program account'];
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    docs: ['Sysvar for program account'];
                    address: 'SysvarRent111111111111111111111111111111111';
                }
            ];
            args: [];
        },
        {
            name: 'buy';
            discriminator: [102, 6, 61, 18, 1, 218, 235, 234];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'mint';
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'boughtToken';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'mint';
                            },
                            {
                                kind: 'account';
                                path: 'payer';
                            }
                        ];
                    };
                },
                {
                    name: 'referralInfo';
                    writable: true;
                },
                {
                    name: 'referrer';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'referralInfoForDl1';
                    docs: ['CHECKED: needs init'];
                    optional: true;
                },
                {
                    name: 'referralInfoForDl2';
                    docs: ['CHECKED: needs init'];
                    optional: true;
                },
                {
                    name: 'referrerDl1';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'referrerDl2';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'tokenCreator';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                },
                {
                    name: 'treasury';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                },
                {
                    name: 'configInfo';
                    writable: true;
                },
                {
                    name: 'associatedTokenProgram';
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'tokenProgram2022';
                },
                {
                    name: 'systemProgram';
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    address: 'SysvarRent111111111111111111111111111111111';
                }
            ];
            args: [
                {
                    name: 'solAmount';
                    type: 'u64';
                },
                {
                    name: 'minOut';
                    type: 'u64';
                }
            ];
        },
        {
            name: 'claim';
            discriminator: [62, 198, 214, 193, 213, 159, 108, 210];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'mint';
                },
                {
                    name: 'payerAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'payer';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram2022';
                            },
                            {
                                kind: 'account';
                                path: 'mint';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'bondingCurveAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'bondingCurve';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram2022';
                            },
                            {
                                kind: 'account';
                                path: 'mint';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'boughtToken';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'mint';
                            },
                            {
                                kind: 'account';
                                path: 'payer';
                            }
                        ];
                    };
                },
                {
                    name: 'tokenProgram2022';
                    docs: ['Program to create mint account and mint tokens'];
                },
                {
                    name: 'associatedTokenProgram';
                    docs: ['Program to create an ATA for receiving position NFT'];
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'systemProgram';
                    docs: ['To create a new program account'];
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    docs: ['Sysvar for program account'];
                    address: 'SysvarRent111111111111111111111111111111111';
                }
            ];
            args: [];
        },
        {
            name: 'closeBoughtToken';
            discriminator: [187, 165, 222, 242, 67, 36, 169, 126];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'user';
                    writable: true;
                },
                {
                    name: 'boughtToken';
                    writable: true;
                }
            ];
            args: [];
        },
        {
            name: 'create';
            discriminator: [24, 30, 200, 40, 5, 28, 7, 119];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'metadata';
                    writable: true;
                },
                {
                    name: 'mint';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'bondingCurveAta';
                    writable: true;
                },
                {
                    name: 'configInfo';
                    writable: true;
                },
                {
                    name: 'associatedTokenProgram';
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'tokenProgram2022';
                },
                {
                    name: 'systemProgram';
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    address: 'SysvarRent111111111111111111111111111111111';
                },
                {
                    name: 'tokenMetadataProgram';
                    address: 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s';
                }
            ];
            args: [
                {
                    name: 'name';
                    type: 'string';
                },
                {
                    name: 'symbol';
                    type: 'string';
                },
                {
                    name: 'uri';
                    type: 'string';
                }
            ];
        },
        {
            name: 'initialize';
            discriminator: [175, 175, 109, 31, 13, 152, 155, 237];
            accounts: [
                {
                    name: 'initializer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'configInfo';
                    writable: true;
                },
                {
                    name: 'systemProgram';
                    address: '11111111111111111111111111111111';
                }
            ];
            args: [
                {
                    name: 'treasury';
                    type: 'pubkey';
                },
                {
                    name: 'withdrawAuthority';
                    type: 'pubkey';
                }
            ];
        },
        {
            name: 'sell';
            discriminator: [51, 230, 133, 164, 1, 127, 131, 173];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'mint';
                },
                {
                    name: 'payerAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'payer';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram2022';
                            },
                            {
                                kind: 'account';
                                path: 'mint';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'boughtToken';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'mint';
                            },
                            {
                                kind: 'account';
                                path: 'payer';
                            }
                        ];
                    };
                },
                {
                    name: 'referralInfo';
                    writable: true;
                },
                {
                    name: 'referrer';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'referralInfoForDl1';
                    docs: ['CHECKED: needs init'];
                    optional: true;
                },
                {
                    name: 'referralInfoForDl2';
                    docs: ['CHECKED: needs init'];
                    optional: true;
                },
                {
                    name: 'referrerDl1';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'referrerDl2';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                    optional: true;
                },
                {
                    name: 'tokenCreator';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                },
                {
                    name: 'treasury';
                    docs: ['CHECKED: needs init'];
                    writable: true;
                },
                {
                    name: 'configInfo';
                    writable: true;
                },
                {
                    name: 'associatedTokenProgram';
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'tokenProgram2022';
                },
                {
                    name: 'systemProgram';
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    address: 'SysvarRent111111111111111111111111111111111';
                }
            ];
            args: [
                {
                    name: 'tokenAmount';
                    type: 'u64';
                },
                {
                    name: 'minOut';
                    type: 'u64';
                }
            ];
        },
        {
            name: 'syncWsol';
            discriminator: [132, 91, 210, 13, 84, 188, 24, 98];
            accounts: [
                {
                    name: 'payer';
                    writable: true;
                    signer: true;
                },
                {
                    name: 'treasury';
                    writable: true;
                },
                {
                    name: 'configInfo';
                    writable: true;
                },
                {
                    name: 'bondingCurve';
                    writable: true;
                },
                {
                    name: 'wsol';
                },
                {
                    name: 'bondingCurveWsolAta';
                    writable: true;
                    pda: {
                        seeds: [
                            {
                                kind: 'account';
                                path: 'bondingCurve';
                            },
                            {
                                kind: 'account';
                                path: 'tokenProgram';
                            },
                            {
                                kind: 'account';
                                path: 'wsol';
                            }
                        ];
                        program: {
                            kind: 'const';
                            value: [
                                140,
                                151,
                                37,
                                143,
                                78,
                                36,
                                137,
                                241,
                                187,
                                61,
                                16,
                                41,
                                20,
                                142,
                                13,
                                131,
                                11,
                                90,
                                19,
                                153,
                                218,
                                255,
                                16,
                                132,
                                4,
                                142,
                                123,
                                216,
                                219,
                                233,
                                248,
                                89
                            ];
                        };
                    };
                },
                {
                    name: 'tokenProgram';
                    docs: ['Program to create mint account and mint tokens'];
                    address: 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA';
                },
                {
                    name: 'associatedTokenProgram';
                    docs: ['Program to create an ATA for receiving position NFT'];
                    address: 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL';
                },
                {
                    name: 'systemProgram';
                    docs: ['To create a new program account'];
                    address: '11111111111111111111111111111111';
                },
                {
                    name: 'rent';
                    docs: ['Sysvar for program account'];
                    address: 'SysvarRent111111111111111111111111111111111';
                }
            ];
            args: [];
        }
    ];
    accounts: [
        {
            name: 'bondingCurve';
            discriminator: [23, 183, 248, 55, 96, 216, 172, 96];
        },
        {
            name: 'boughtToken';
            discriminator: [151, 170, 199, 180, 228, 69, 83, 210];
        },
        {
            name: 'configInfo';
            discriminator: [254, 198, 155, 179, 64, 33, 78, 155];
        },
        {
            name: 'referralInfo';
            discriminator: [234, 101, 199, 136, 0, 181, 74, 148];
        }
    ];
    events: [
        {
            name: 'completeEvent';
            discriminator: [95, 114, 97, 156, 212, 46, 152, 8];
        },
        {
            name: 'createTokenEvent';
            discriminator: [4, 4, 86, 151, 191, 94, 245, 193];
        },
        {
            name: 'tradeEvent';
            discriminator: [189, 219, 127, 211, 78, 230, 97, 238];
        }
    ];
    errors: [
        {
            code: 6000;
            name: 'invalidAccessRight';
            msg: 'GmacError Error';
        },
        {
            code: 6001;
            name: 'invalidLpAmount';
        },
        {
            code: 6002;
            name: 'tokenOutputAmountTooHigh';
        },
        {
            code: 6003;
            name: 'valueMustBeGreaterThanZero';
        },
        {
            code: 6004;
            name: 'cannotRefToYourself';
        },
        {
            code: 6005;
            name: 'exceedsSlipage';
        },
        {
            code: 6006;
            name: 'insufficientBalance';
        },
        {
            code: 6007;
            name: 'invalidCurveComplete';
        },
        {
            code: 6008;
            name: 'invalidReferrer';
        }
    ];
    types: [
        {
            name: 'bondingCurve';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'tokenCreator';
                        type: 'pubkey';
                    },
                    {
                        name: 'bump';
                        type: 'u8';
                    },
                    {
                        name: 'complete';
                        type: 'bool';
                    },
                    {
                        name: 'liquidityAdded';
                        type: 'bool';
                    },
                    {
                        name: 'syncedSol';
                        type: 'bool';
                    },
                    {
                        name: 'mint';
                        type: 'pubkey';
                    },
                    {
                        name: 'virtualSolReserve';
                        type: 'u64';
                    },
                    {
                        name: 'virtualTokenReserve';
                        type: 'u64';
                    },
                    {
                        name: 'tokenDebt';
                        type: 'u64';
                    }
                ];
            };
        },
        {
            name: 'boughtToken';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'owner';
                        type: 'pubkey';
                    },
                    {
                        name: 'mint';
                        type: 'pubkey';
                    },
                    {
                        name: 'balance';
                        type: 'u64';
                    },
                    {
                        name: 'bump';
                        type: 'u8';
                    }
                ];
            };
        },
        {
            name: 'completeEvent';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'mint';
                        type: 'pubkey';
                    },
                    {
                        name: 'timestamp';
                        type: 'u64';
                    }
                ];
            };
        },
        {
            name: 'configInfo';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'owner';
                        type: 'pubkey';
                    },
                    {
                        name: 'treasury';
                        type: 'pubkey';
                    },
                    {
                        name: 'withdrawAuthority';
                        type: 'pubkey';
                    },
                    {
                        name: 'bump';
                        type: 'u8';
                    }
                ];
            };
        },
        {
            name: 'createTokenEvent';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'name';
                        type: 'string';
                    },
                    {
                        name: 'symbol';
                        type: 'string';
                    },
                    {
                        name: 'uri';
                        type: 'string';
                    },
                    {
                        name: 'mint';
                        type: 'pubkey';
                    },
                    {
                        name: 'tokenCreator';
                        type: 'pubkey';
                    },
                    {
                        name: 'timestamp';
                        type: 'u64';
                    }
                ];
            };
        },
        {
            name: 'referralInfo';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'referrer';
                        type: {
                            option: 'pubkey';
                        };
                    },
                    {
                        name: 'user';
                        type: 'pubkey';
                    },
                    {
                        name: 'initialized';
                        type: 'bool';
                    },
                    {
                        name: 'bump';
                        type: 'u8';
                    }
                ];
            };
        },
        {
            name: 'tradeEvent';
            type: {
                kind: 'struct';
                fields: [
                    {
                        name: 'solAmount';
                        type: 'u64';
                    },
                    {
                        name: 'tokenAmount';
                        type: 'u64';
                    },
                    {
                        name: 'mint';
                        type: 'pubkey';
                    },
                    {
                        name: 'virtualSolReserve';
                        type: 'u64';
                    },
                    {
                        name: 'virtualTokenReserve';
                        type: 'u64';
                    },
                    {
                        name: 'trader';
                        type: 'pubkey';
                    },
                    {
                        name: 'isBuy';
                        type: 'bool';
                    },
                    {
                        name: 'balance';
                        type: 'u64';
                    },
                    {
                        name: 'timestamp';
                        type: 'u64';
                    }
                ];
            };
        }
    ];
};
