import { PublicKey } from '@solana/web3.js';
import * as anchor from '@coral-xyz/anchor';
export interface ConfigInfo {
    owner: PublicKey;
    treasury: PublicKey;
    withdrawAuthority: PublicKey;
    bump: number;
}
export interface BondingCurveInfo {
    tokenCreator: PublicKey;
    bump: number;
    complete: boolean;
    liquidityAdded: boolean;
    syncedSol: boolean;
    mint: PublicKey;
    virtualSolReserve: anchor.BN;
    virtualTokenReserve: anchor.BN;
    tokenDebt: anchor.BN;
    progress: number;
}
export interface BoughtToken {
    owner: PublicKey;
    mint: PublicKey;
    balance: anchor.BN;
    bump: number;
}
export interface ReferralInfo {
    referrer: PublicKey | null;
    user: PublicKey;
    initialized: boolean;
    bump: number;
}
export type OmniEventName = 'createTokenEvent' | 'tradeEvent' | 'completeEvent';
export interface OmniEvent {
    eventName: OmniEventName;
}
export interface CreateTokenEvent extends OmniEvent {
    name: string;
    symbol: string;
    uri: string;
    mint: PublicKey;
    tokenCreator: PublicKey;
    timestamp: number;
}
export interface TradeEvent extends OmniEvent {
    solAmount: number;
    tokenAmount: anchor.BN;
    mint: PublicKey;
    virtualSolReserve: anchor.BN;
    virtualTokenReserve: anchor.BN;
    trader: PublicKey;
    isBuy: boolean;
    balance: anchor.BN;
    timestamp: number;
}
export interface CompleteEvent extends OmniEvent {
    mint: PublicKey;
    timestamp: number;
}
